//Set the font size according to the mobile plateform
function getFontSize(fontSize) {
    document.documentElement.style.setProperty("font-size", `${fontSize}px`);
}

//Return Font Size of body
function returnFontSize() {
    let bodyFontSize = window.getComputedStyle(document.body).getPropertyValue("font-size");
    return parseFloat(bodyFontSize);
}

//Send a callback on click of the internal links of paragraph
$(".ew-body a").click(function(event) {
    event.preventDefault();
    let intLink = {
        clickType: "internalLink",
        internalLinkObjData: decodeURIComponent($(this).attr("href")).replace(/[\s\n]+/g, " ")
    };
    sendUrlToApp(intLink);
});

//Send the related article url string to the mobile app
$(".plink_webview_url").click(function(){
    let pLinkUrlStr = decodeURIComponent($(this).attr("plink_url")).replace(/[\s\n]+/g, " ");
    let plinkUuid = $(this).parent('article').attr("data-uuid"); 
    let checkIsPremiumFlag = $(this).parent('article').hasClass("teaser--content-paid"); 
    let plinkUrlData = {
        clickType: "relatedArticleLink",
        permalinkUrlData:pLinkUrlStr,
        permalinkUuid:plinkUuid,
        isPremiumFlag:checkIsPremiumFlag
    };
    sendUrlToApp(plinkUrlData);
});

//Send the mailto string to the mobile app
$(".mailto_web").click(function(event){
    event.preventDefault();
    let mailtoStr = decodeURIComponent($(this).attr("href")).replace(/[\s\n]+/g, " ");
    let mailTORelatedData = {
        clickType: "mailToLink",
        clickedMailToData:mailtoStr
    };
    sendUrlToApp(mailTORelatedData);
});

//Send the Image related data to app
$(".figure-img-container .figure-img").off('click').on('click', function(e) {
    e.preventDefault();
        

    let clikedImageData = [];
    let srcset = $(this).attr("srcset");
    let src = $(this).attr("src");

    let fullClickedCaption = $(this).parent().siblings().text().trim();


    let clickedCaption = fullClickedCaption.replace(/Photo by\s*.+/, "").trim();
    clickedCaption = clickedCaption.replace(/[\s\n]+/g, " ");

    let ClickeddataWidth = $(this).parent().parent().attr("data-width");
    let clickeddataHeight = $(this).parent().parent().attr("data-height");
    let clickeddataUuid = $(this).parent().parent().attr("data-uuid");

    let checkClickedAuthorName = fullClickedCaption.match(/Photo by\s+(.*)/);
    let clickedFullAuthorName = "";
    if(checkClickedAuthorName)
    {
        clickedFullAuthorName = checkClickedAuthorName[1];
    }

    clikedImageData.push({
        clickedImageUrl: src,
        clickedImageSrcSet: srcset,
        clickedCaption: clickedCaption,
        clickedDataWidth: ClickeddataWidth,
        clickedDataHeight: clickeddataHeight,
        clickedAuthorName: clickedFullAuthorName,
        clickedDataUuid:clickeddataUuid
    });


    let imageDataArray = [];
    $("figure.opener-image").each(function() {
        
        let dataWidth = $(this).attr("data-width");
        let dataHeight = $(this).attr("data-height");
        let dataUuid = $(this).attr("data-uuid");
        let imageUrl = $(this).find("img").attr("src");
        let imageSrcSet = $(this).find("img").attr("srcset");
        let full_caption = $(this).find("figcaption").text();
        let caption = full_caption.replace(/Photo by\s*.+/, "").trim();
        caption = caption.replace(/[\s\n]+/g, " ");

        let checkAuthorName = full_caption.match(/Photo by\s*(.+)/);
        let fullAuthorName = "";
        if(checkAuthorName)
        {
            fullAuthorName = checkAuthorName[1];
        }

        imageDataArray.push({
            imageUrl: imageUrl,
            imageSrcSet: imageSrcSet,
            caption: caption,
            dataWidth: dataWidth,
            dataHeight: dataHeight,
            dataUuid:dataUuid,
            authorName: fullAuthorName
        });

    });

    let imageRelatedData = {
        clickType: "allImageLink",
        clikedImageData:clikedImageData,
        allImageData:imageDataArray
    };

    sendUrlToApp(imageRelatedData);
});
  
function sendUrlToApp(postData) {
    if (window.webkit && window.webkit.messageHandlers && window.webkit.messageHandlers.webviewMessage) { //For iOS
        window.webkit.messageHandlers.webviewMessage.postMessage(postData);
    }
    else if (window.Android) { // For Android
        window.Android.postMessage(JSON.stringify(postData));
    }
    else
    {
        console.log(postData);
    }
}

$(document).ready(function() {
    
    // Enable swipe feature on the mobile for carousal
    let touchStartX = 0;
    let touchEndX = 0;

    function handleSwipe() {
        let threshold = 75; // Minimum swipe distance in pixels
        if (touchEndX < touchStartX - threshold) {
            $(".slide").carousel("next");
        } else if (touchEndX > touchStartX + threshold) {
            $(".slide").carousel("prev");
        }
    }

    $(".slide").on("touchstart", function(event) {
        touchStartX = event.originalEvent.touches[0].clientX;
        touchEndX = touchStartX;
    });

    $(".slide").on("touchmove", function(event) {
        touchEndX = event.originalEvent.touches[0].clientX;
        event.preventDefault(); // Prevent default action to stop moving to the next article
    });

    $(".slide").on("touchend", function(event) {
        handleSwipe();
    });

});

document.addEventListener("DOMContentLoaded", function () {
    const lazyParagraphs = document.querySelectorAll('.ew-body');
    const lazyIframes = document.querySelectorAll('iframe');
    const lazyImages = document.querySelectorAll('img');

    const observer = new IntersectionObserver((entries, observer) => {
      entries.forEach(entry => {
        if (entry.isIntersecting) {
          const element = entry.target;
          element.classList.add('loaded');
          observer.unobserve(element); // Stop observing after loading

          // Add loading="lazy" attribute to iframes and images if not already present
          if (element.tagName.toLowerCase() === 'iframe' || element.tagName.toLowerCase() === 'img') {
            if (!element.hasAttribute('loading')) {
              element.setAttribute('loading', 'lazy');
            }
          }
        }
      });
    }, {
      threshold: 0.1 // Trigger when 10% of the element is visible
    });

    lazyParagraphs.forEach(paragraph => {
      paragraph.classList.add('lazy-loading');  // Add placeholder effect
      observer.observe(paragraph);              // Observe the paragraph
    });

    lazyIframes.forEach(iframe => {
      observer.observe(iframe);                 // Observe the iframe
    });

    lazyImages.forEach(img => {
      observer.observe(img);                    // Observe the image
    });
});